import { Dict_Apis } from "../dict/apis";
import store from "../store";

const baseURL = Dict_Apis.auth;

export default function (url, options = {}) {
  return new Promise((resolve) => {
    if (options.method && options.method !== "GET")
      uni.showLoading({ title: "加载中" });

    uni.request({
      ...options,
      url: (options.baseURL ? options.baseURL : baseURL) + url,
      header: {
        Authorization: "Bearer " + uni.getStorageSync("access-token"),
      },
      success(res) {
        uni.hideLoading();
        if (res.statusCode === 200) {
          let data = res.data;
          if (data.errorNo === 401) {
            store.dispatch("logout");
          }
          resolve(data);
        } else {
          resolve({
            code: res.statusCode,
            msg: res.errMsg,
          });
        }
      },
      fail(err) {
        uni.hideLoading();
        console.log("error", err);
        resolve({
          code: 500,
          msg: err.errMsg,
        });
      },
    });
  });
}
