import Vue from "vue";
import Vuex from "vuex";
import { getUserInfo } from "../services/https/user";

Vue.use(Vuex);

const store = new Vuex.Store({
  state: {
    hasLogin: true,
    token: "",
    userInfo: {},
    openid: null,
  },
  mutations: {
    login(state, token) {
      state.hasLogin = true;
      if (token) state.token = token;
    },
    setUserInfo(state, userinfo) {
      state.userInfo = userinfo;
    },
    logout(state) {
      state.hasLogin = false;
      state.token = "";
      state.userInfo = {};
    },
  },
  getters: {},
  actions: {
    login({ commit }, token) {
      commit("login");
      uni.setStorageSync("access-token", token);
    },
    logout({ commit }) {
      commit("logout");
      uni.removeStorageSync("access-token");
    },

    async getUserInfo({ commit }) {
      const res = await getUserInfo();
      if (res.errorNo !== 200) return;
      commit("login");
      commit("setUserInfo", res.result.user);
    },

    getPhoneNumber: function ({ commit }, univerifyInfo) {
      return new Promise((resolve, reject) => {
        uni.request({
          url: "https://97fca9f2-41f6-449f-a35e-3f135d4c3875.bspapp.com/http/univerify-login",
          method: "POST",
          data: univerifyInfo,
          success: (res) => {
            const data = res.data;
            if (data.success) {
              resolve(data.phoneNumber);
            } else {
              reject(res);
            }
          },
          fail: (err) => {
            reject(res);
          },
        });
      });
    },
  },
});

export default store;
